![logo](logo.png)

**hankl is a lightweight Python implementation of the FFTLog algorithm for Cosmology**


[![GitHub](https://img.shields.io/badge/GitHub-minaskar%2Fhankl-blue)](https://github.com/minaskar/hankl)
[![Build Status](https://api.travis-ci.com/minaskar/hankl.svg?branch=master&status=passed)](https://travis-ci.com/minaskar/hankl)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/minaskar/hankl/blob/master/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/hankl/badge/?version=latest)](https://hankl.readthedocs.io/en/latest/?badge=latest)


## Documentation

Read the docs at [hankl.readthedocs.io](https://hankl.readthedocs.io)


## Installation

To install hankl using pip run:

```bash
pip install hankl
```

Alternatively, install the latest version of hankl from source:

```bash
git clone https://github.com/minaskar/hankl.git
cd hankl
pip install -r requirements.txt
pip install .
```

You need numpy and scipy to install hankl.


## Licence

Copyright 2020 Minas Karamanis and contributors.

hankl is free software made available under the GPL-3.0 License. For details see the `LICENSE` file.


## Contributions

We welcome all contributions to hankl via Pull Requests. Let us know about any issues or questions about hankl.